@@ -1,10 +1,8 @@
-use v5.24;
-
 package Dist::Zilla::Plugin::LocalHTML;
 
 # ABSTRACT: create CSS-rich HTML pages from the POD-aware files for local browsing
 
-our $VERSION = 'v0.1.1';
+our $VERSION = 'v0.2.0';
 
 
 use Moose::Autobox;
@@ -101,7 +99,7 @@ sub base_filename {
     $basename =~ s{(\.[^.]*)?$}{}n;
     $path = File::Spec->canonpath($path);
     my @dirs = File::Spec->splitdir($path);
-    shift @dirs if @dirs && $dirs[0] =~ /^(lib|bin|scripts)$/n;
+    shift @dirs if @dirs && $dirs[0] =~ /^(lib|bin|scripts)$/;
     return join( "-", @dirs, "$basename.html" );
 }
 
@@ -163,7 +161,7 @@ Dist::Zilla::Plugin::LocalHTML - create CSS-rich HTML pages from the POD-aware f
 
 =head1 VERSION
 
-version v0.1.1
+version v0.2.0
 
 =head1 SYNOPSIS
 
