@@ -1,10 +1,8 @@
-use v5.24;
-
 package Dist::Zilla::Plugin::LocalHTML::Pod2HTML;
 
 # ABSTRACT: Pod::Simple::HTML wrapper to generate local links for project modules.
 
-our $VERSION = 'v0.1.1';
+our $VERSION = 'v0.2.0';
 
 use File::Spec;
 use Data::Dumper;
@@ -57,7 +55,11 @@ around do_pod_link => sub {
             my $lpRx   = $this->prefixRx;
             my $to     = "" . $link->attr('to');
             my $toFile = $this->_mod2file($to);
-            if ( ( defined($lpRx) && $to =~ /^$lpRx/n )
+            $this->log_debug("'$to' matches local prefix")
+              if defined($lpRx) && $to =~ /^$lpRx/;
+            $this->log_debug("'$toFile' is in local_files map")
+              if $this->local_files->{$toFile};
+            if ( ( defined($lpRx) && $to =~ /^$lpRx/ )
                 || $this->local_files->{$toFile} )
             {
                 # Local link
@@ -118,7 +120,7 @@ Dist::Zilla::Plugin::LocalHTML::Pod2HTML - Pod::Simple::HTML wrapper to generate
 
 =head1 VERSION
 
-version v0.1.1
+version v0.2.0
 
 =head1 ATTRIBUTES
 
